Module Name: src
Committed By: roy
Date: Mon Oct 6 18:22:30 UTC 2014
Modified Files:
src/external/bsd/dhcpcd/dist: arp.c arp.h auth.c auth.h bpf-filter.h
common.c common.h config.h control.c control.h defs.h dev.h
dhcp-common.c dhcp-common.h dhcp.c dhcp.h dhcp6.c dhcp6.h
dhcpcd-definitions.conf dhcpcd-embedded.c dhcpcd-embedded.h
dhcpcd-run-hooks.8.in dhcpcd-run-hooks.in dhcpcd.8.in dhcpcd.c
dhcpcd.conf dhcpcd.conf.5.in dhcpcd.h duid.c duid.h eloop.c eloop.h
if-bsd.c if-options.c if-options.h if.c if.h ipv4.c ipv4.h ipv4ll.c
ipv4ll.h ipv6.c ipv6.h ipv6nd.c ipv6nd.h script.c script.h
src/external/bsd/dhcpcd/dist/crypt: crypt.h hmac_md5.c
src/external/bsd/dhcpcd/dist/dhcpcd-hooks: 01-test 02-dump 10-mtu
10-wpa_supplicant 15-timezone 20-resolv.conf 29-lookup-hostname
30-hostname 50-ntp.conf 50-ypbind
Log Message:
Sync
To generate a diff of this commit:
cvs rdiff -u -r1.1.1.14 -r1.2 src/external/bsd/dhcpcd/dist/arp.c \
src/external/bsd/dhcpcd/dist/ipv6.c
cvs rdiff -u -r1.1.1.4 -r1.2 src/external/bsd/dhcpcd/dist/arp.h \
src/external/bsd/dhcpcd/dist/auth.c \
src/external/bsd/dhcpcd/dist/dhcpcd-embedded.h
cvs rdiff -u -r1.1.1.2 -r1.2 src/external/bsd/dhcpcd/dist/auth.h
cvs rdiff -u -r1.4 -r1.5 src/external/bsd/dhcpcd/dist/bpf-filter.h
cvs rdiff -u -r1.1.1.15 -r1.2 src/external/bsd/dhcpcd/dist/common.c
cvs rdiff -u -r1.1.1.11 -r1.2 src/external/bsd/dhcpcd/dist/common.h
cvs rdiff -u -r1.1.1.28 -r1.2 src/external/bsd/dhcpcd/dist/config.h
cvs rdiff -u -r1.1.1.9 -r1.2 src/external/bsd/dhcpcd/dist/control.c \
src/external/bsd/dhcpcd/dist/dhcp6.h
cvs rdiff -u -r1.1.1.6 -r1.2 src/external/bsd/dhcpcd/dist/control.h \
src/external/bsd/dhcpcd/dist/dhcpcd-definitions.conf \
src/external/bsd/dhcpcd/dist/duid.h src/external/bsd/dhcpcd/dist/if.c \
src/external/bsd/dhcpcd/dist/if.h
cvs rdiff -u -r1.1.1.46 -r1.2 src/external/bsd/dhcpcd/dist/defs.h
cvs rdiff -u -r1.1.1.5 -r1.2 src/external/bsd/dhcpcd/dist/dev.h \
src/external/bsd/dhcpcd/dist/ipv4.h src/external/bsd/dhcpcd/dist/ipv6nd.h
cvs rdiff -u -r1.1.1.10 -r1.2 src/external/bsd/dhcpcd/dist/dhcp-common.c \
src/external/bsd/dhcpcd/dist/eloop.c src/external/bsd/dhcpcd/dist/eloop.h \
src/external/bsd/dhcpcd/dist/ipv4ll.c
cvs rdiff -u -r1.1.1.7 -r1.2 src/external/bsd/dhcpcd/dist/dhcp-common.h \
src/external/bsd/dhcpcd/dist/ipv4.c
cvs rdiff -u -r1.17 -r1.18 src/external/bsd/dhcpcd/dist/dhcp.c
cvs rdiff -u -r1.1.1.21 -r1.2 src/external/bsd/dhcpcd/dist/dhcp.h
cvs rdiff -u -r1.1.1.17 -r1.2 src/external/bsd/dhcpcd/dist/dhcp6.c
cvs rdiff -u -r1.1.1.8 -r1.2 src/external/bsd/dhcpcd/dist/dhcpcd-embedded.c \
src/external/bsd/dhcpcd/dist/duid.c
cvs rdiff -u -r1.7 -r1.8 src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.8.in
cvs rdiff -u -r1.1.1.20 -r1.2 \
src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.in \
src/external/bsd/dhcpcd/dist/dhcpcd.h
cvs rdiff -u -r1.31 -r1.32 src/external/bsd/dhcpcd/dist/dhcpcd.8.in
cvs rdiff -u -r1.11 -r1.12 src/external/bsd/dhcpcd/dist/dhcpcd.c \
src/external/bsd/dhcpcd/dist/dhcpcd.conf.5.in
cvs rdiff -u -r1.10 -r1.11 src/external/bsd/dhcpcd/dist/dhcpcd.conf \
src/external/bsd/dhcpcd/dist/if-bsd.c
cvs rdiff -u -r1.12 -r1.13 src/external/bsd/dhcpcd/dist/if-options.c \
src/external/bsd/dhcpcd/dist/ipv6nd.c
cvs rdiff -u -r1.1.1.23 -r1.2 src/external/bsd/dhcpcd/dist/if-options.h
cvs rdiff -u -r1.1.1.3 -r1.2 src/external/bsd/dhcpcd/dist/ipv4ll.h \
src/external/bsd/dhcpcd/dist/script.h
cvs rdiff -u -r1.1.1.12 -r1.2 src/external/bsd/dhcpcd/dist/ipv6.h
cvs rdiff -u -r1.9 -r1.10 src/external/bsd/dhcpcd/dist/script.c
cvs rdiff -u -r1.1.1.2 -r1.2 src/external/bsd/dhcpcd/dist/crypt/crypt.h
cvs rdiff -u -r1.1.1.4 -r1.2 src/external/bsd/dhcpcd/dist/crypt/hmac_md5.c
cvs rdiff -u -r1.1.1.7 -r1.2 \
src/external/bsd/dhcpcd/dist/dhcpcd-hooks/01-test
cvs rdiff -u -r1.1.1.4 -r1.2 \
src/external/bsd/dhcpcd/dist/dhcpcd-hooks/02-dump
cvs rdiff -u -r1.1.1.8 -r1.2 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-mtu \
src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ypbind
cvs rdiff -u -r1.1.1.5 -r1.2 \
src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-wpa_supplicant \
src/external/bsd/dhcpcd/dist/dhcpcd-hooks/29-lookup-hostname
cvs rdiff -u -r1.1.1.2 -r1.2 \
src/external/bsd/dhcpcd/dist/dhcpcd-hooks/15-timezone
cvs rdiff -u -r1.1.1.15 -r1.2 \
src/external/bsd/dhcpcd/dist/dhcpcd-hooks/20-resolv.conf
cvs rdiff -u -r1.1.1.10 -r1.2 \
src/external/bsd/dhcpcd/dist/dhcpcd-hooks/30-hostname
cvs rdiff -u -r1.1.1.14 -r1.2 \
src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ntp.conf
Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.
Modified files:
Index: src/external/bsd/dhcpcd/dist/arp.c
diff -u src/external/bsd/dhcpcd/dist/arp.c:1.1.1.14 src/external/bsd/dhcpcd/dist/arp.c:1.2
--- src/external/bsd/dhcpcd/dist/arp.c:1.1.1.14 Tue Sep 16 22:23:18 2014
+++ src/external/bsd/dhcpcd/dist/arp.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: arp.c,v 1.1.1.14 2014/09/16 22:23:18 roy Exp $");
+ __RCSID("$NetBSD: arp.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/ipv6.c
diff -u src/external/bsd/dhcpcd/dist/ipv6.c:1.1.1.14 src/external/bsd/dhcpcd/dist/ipv6.c:1.2
--- src/external/bsd/dhcpcd/dist/ipv6.c:1.1.1.14 Mon Oct 6 18:20:18 2014
+++ src/external/bsd/dhcpcd/dist/ipv6.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: ipv6.c,v 1.1.1.14 2014/10/06 18:20:18 roy Exp $");
+ __RCSID("$NetBSD: ipv6.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/arp.h
diff -u src/external/bsd/dhcpcd/dist/arp.h:1.1.1.4 src/external/bsd/dhcpcd/dist/arp.h:1.2
--- src/external/bsd/dhcpcd/dist/arp.h:1.1.1.4 Tue Feb 25 13:14:30 2014
+++ src/external/bsd/dhcpcd/dist/arp.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: arp.h,v 1.1.1.4 2014/02/25 13:14:30 roy Exp $ */
+/* $NetBSD: arp.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/auth.c
diff -u src/external/bsd/dhcpcd/dist/auth.c:1.1.1.4 src/external/bsd/dhcpcd/dist/auth.c:1.2
--- src/external/bsd/dhcpcd/dist/auth.c:1.1.1.4 Sat Jun 14 20:51:05 2014
+++ src/external/bsd/dhcpcd/dist/auth.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: auth.c,v 1.1.1.4 2014/06/14 20:51:05 roy Exp $");
+ __RCSID("$NetBSD: auth.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcpcd-embedded.h
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-embedded.h:1.1.1.4 src/external/bsd/dhcpcd/dist/dhcpcd-embedded.h:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-embedded.h:1.1.1.4 Mon Jul 14 11:45:06 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-embedded.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: dhcpcd-embedded.h,v 1.1.1.4 2014/07/14 11:45:06 roy Exp $ */
+/* $NetBSD: dhcpcd-embedded.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/auth.h
diff -u src/external/bsd/dhcpcd/dist/auth.h:1.1.1.2 src/external/bsd/dhcpcd/dist/auth.h:1.2
--- src/external/bsd/dhcpcd/dist/auth.h:1.1.1.2 Sat Jun 14 20:51:06 2014
+++ src/external/bsd/dhcpcd/dist/auth.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: auth.h,v 1.1.1.2 2014/06/14 20:51:06 roy Exp $ */
+/* $NetBSD: auth.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/bpf-filter.h
diff -u src/external/bsd/dhcpcd/dist/bpf-filter.h:1.4 src/external/bsd/dhcpcd/dist/bpf-filter.h:1.5
--- src/external/bsd/dhcpcd/dist/bpf-filter.h:1.4 Sat Jun 14 20:55:37 2014
+++ src/external/bsd/dhcpcd/dist/bpf-filter.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: bpf-filter.h,v 1.4 2014/06/14 20:55:37 roy Exp $ */
+/* $NetBSD: bpf-filter.h,v 1.5 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/common.c
diff -u src/external/bsd/dhcpcd/dist/common.c:1.1.1.15 src/external/bsd/dhcpcd/dist/common.c:1.2
--- src/external/bsd/dhcpcd/dist/common.c:1.1.1.15 Sat Jun 14 20:51:03 2014
+++ src/external/bsd/dhcpcd/dist/common.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: common.c,v 1.1.1.15 2014/06/14 20:51:03 roy Exp $");
+ __RCSID("$NetBSD: common.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/common.h
diff -u src/external/bsd/dhcpcd/dist/common.h:1.1.1.11 src/external/bsd/dhcpcd/dist/common.h:1.2
--- src/external/bsd/dhcpcd/dist/common.h:1.1.1.11 Sat Jun 14 20:51:06 2014
+++ src/external/bsd/dhcpcd/dist/common.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: common.h,v 1.1.1.11 2014/06/14 20:51:06 roy Exp $ */
+/* $NetBSD: common.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/config.h
diff -u src/external/bsd/dhcpcd/dist/config.h:1.1.1.28 src/external/bsd/dhcpcd/dist/config.h:1.2
--- src/external/bsd/dhcpcd/dist/config.h:1.1.1.28 Mon Oct 6 18:20:19 2014
+++ src/external/bsd/dhcpcd/dist/config.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: config.h,v 1.1.1.28 2014/10/06 18:20:19 roy Exp $ */
+/* $NetBSD: config.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/* netbsd */
#define SYSCONFDIR "/etc"
Index: src/external/bsd/dhcpcd/dist/control.c
diff -u src/external/bsd/dhcpcd/dist/control.c:1.1.1.9 src/external/bsd/dhcpcd/dist/control.c:1.2
--- src/external/bsd/dhcpcd/dist/control.c:1.1.1.9 Mon Oct 6 18:20:16 2014
+++ src/external/bsd/dhcpcd/dist/control.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: control.c,v 1.1.1.9 2014/10/06 18:20:16 roy Exp $");
+ __RCSID("$NetBSD: control.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcp6.h
diff -u src/external/bsd/dhcpcd/dist/dhcp6.h:1.1.1.9 src/external/bsd/dhcpcd/dist/dhcp6.h:1.2
--- src/external/bsd/dhcpcd/dist/dhcp6.h:1.1.1.9 Mon Oct 6 18:20:19 2014
+++ src/external/bsd/dhcpcd/dist/dhcp6.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: dhcp6.h,v 1.1.1.9 2014/10/06 18:20:19 roy Exp $ */
+/* $NetBSD: dhcp6.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/control.h
diff -u src/external/bsd/dhcpcd/dist/control.h:1.1.1.6 src/external/bsd/dhcpcd/dist/control.h:1.2
--- src/external/bsd/dhcpcd/dist/control.h:1.1.1.6 Tue Sep 16 22:23:21 2014
+++ src/external/bsd/dhcpcd/dist/control.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: control.h,v 1.1.1.6 2014/09/16 22:23:21 roy Exp $ */
+/* $NetBSD: control.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcpcd-definitions.conf
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-definitions.conf:1.1.1.6 src/external/bsd/dhcpcd/dist/dhcpcd-definitions.conf:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-definitions.conf:1.1.1.6 Mon Oct 6 18:20:19 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-definitions.conf Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-# $NetBSD: dhcpcd-definitions.conf,v 1.1.1.6 2014/10/06 18:20:19 roy Exp $
+# $NetBSD: dhcpcd-definitions.conf,v 1.2 2014/10/06 18:22:29 roy Exp $
# Copyright (c) 2006-2014 Roy Marples
# All rights reserved
Index: src/external/bsd/dhcpcd/dist/duid.h
diff -u src/external/bsd/dhcpcd/dist/duid.h:1.1.1.6 src/external/bsd/dhcpcd/dist/duid.h:1.2
--- src/external/bsd/dhcpcd/dist/duid.h:1.1.1.6 Sat Jun 14 20:51:09 2014
+++ src/external/bsd/dhcpcd/dist/duid.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: duid.h,v 1.1.1.6 2014/06/14 20:51:09 roy Exp $ */
+/* $NetBSD: duid.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/if.c
diff -u src/external/bsd/dhcpcd/dist/if.c:1.1.1.6 src/external/bsd/dhcpcd/dist/if.c:1.2
--- src/external/bsd/dhcpcd/dist/if.c:1.1.1.6 Mon Oct 6 18:20:16 2014
+++ src/external/bsd/dhcpcd/dist/if.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: if.c,v 1.1.1.6 2014/10/06 18:20:16 roy Exp $");
+ __RCSID("$NetBSD: if.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/if.h
diff -u src/external/bsd/dhcpcd/dist/if.h:1.1.1.6 src/external/bsd/dhcpcd/dist/if.h:1.2
--- src/external/bsd/dhcpcd/dist/if.h:1.1.1.6 Mon Oct 6 18:20:19 2014
+++ src/external/bsd/dhcpcd/dist/if.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: if.h,v 1.1.1.6 2014/10/06 18:20:19 roy Exp $ */
+/* $NetBSD: if.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/defs.h
diff -u src/external/bsd/dhcpcd/dist/defs.h:1.1.1.46 src/external/bsd/dhcpcd/dist/defs.h:1.2
--- src/external/bsd/dhcpcd/dist/defs.h:1.1.1.46 Mon Oct 6 18:20:19 2014
+++ src/external/bsd/dhcpcd/dist/defs.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: defs.h,v 1.1.1.46 2014/10/06 18:20:19 roy Exp $ */
+/* $NetBSD: defs.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dev.h
diff -u src/external/bsd/dhcpcd/dist/dev.h:1.1.1.5 src/external/bsd/dhcpcd/dist/dev.h:1.2
--- src/external/bsd/dhcpcd/dist/dev.h:1.1.1.5 Mon Oct 6 18:20:19 2014
+++ src/external/bsd/dhcpcd/dist/dev.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: dev.h,v 1.1.1.5 2014/10/06 18:20:19 roy Exp $ */
+/* $NetBSD: dev.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/ipv4.h
diff -u src/external/bsd/dhcpcd/dist/ipv4.h:1.1.1.5 src/external/bsd/dhcpcd/dist/ipv4.h:1.2
--- src/external/bsd/dhcpcd/dist/ipv4.h:1.1.1.5 Sat Jun 14 20:51:09 2014
+++ src/external/bsd/dhcpcd/dist/ipv4.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: ipv4.h,v 1.1.1.5 2014/06/14 20:51:09 roy Exp $ */
+/* $NetBSD: ipv4.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/ipv6nd.h
diff -u src/external/bsd/dhcpcd/dist/ipv6nd.h:1.1.1.5 src/external/bsd/dhcpcd/dist/ipv6nd.h:1.2
--- src/external/bsd/dhcpcd/dist/ipv6nd.h:1.1.1.5 Tue Sep 16 22:23:21 2014
+++ src/external/bsd/dhcpcd/dist/ipv6nd.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: ipv6nd.h,v 1.1.1.5 2014/09/16 22:23:21 roy Exp $ */
+/* $NetBSD: ipv6nd.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcp-common.c
diff -u src/external/bsd/dhcpcd/dist/dhcp-common.c:1.1.1.10 src/external/bsd/dhcpcd/dist/dhcp-common.c:1.2
--- src/external/bsd/dhcpcd/dist/dhcp-common.c:1.1.1.10 Mon Oct 6 18:20:17 2014
+++ src/external/bsd/dhcpcd/dist/dhcp-common.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: dhcp-common.c,v 1.1.1.10 2014/10/06 18:20:17 roy Exp $");
+ __RCSID("$NetBSD: dhcp-common.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/eloop.c
diff -u src/external/bsd/dhcpcd/dist/eloop.c:1.1.1.10 src/external/bsd/dhcpcd/dist/eloop.c:1.2
--- src/external/bsd/dhcpcd/dist/eloop.c:1.1.1.10 Tue Sep 16 22:23:18 2014
+++ src/external/bsd/dhcpcd/dist/eloop.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: eloop.c,v 1.1.1.10 2014/09/16 22:23:18 roy Exp $");
+ __RCSID("$NetBSD: eloop.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/eloop.h
diff -u src/external/bsd/dhcpcd/dist/eloop.h:1.1.1.10 src/external/bsd/dhcpcd/dist/eloop.h:1.2
--- src/external/bsd/dhcpcd/dist/eloop.h:1.1.1.10 Tue Sep 16 22:23:21 2014
+++ src/external/bsd/dhcpcd/dist/eloop.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: eloop.h,v 1.1.1.10 2014/09/16 22:23:21 roy Exp $ */
+/* $NetBSD: eloop.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/ipv4ll.c
diff -u src/external/bsd/dhcpcd/dist/ipv4ll.c:1.1.1.10 src/external/bsd/dhcpcd/dist/ipv4ll.c:1.2
--- src/external/bsd/dhcpcd/dist/ipv4ll.c:1.1.1.10 Sat Jun 14 20:51:05 2014
+++ src/external/bsd/dhcpcd/dist/ipv4ll.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: ipv4ll.c,v 1.1.1.10 2014/06/14 20:51:05 roy Exp $");
+ __RCSID("$NetBSD: ipv4ll.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcp-common.h
diff -u src/external/bsd/dhcpcd/dist/dhcp-common.h:1.1.1.7 src/external/bsd/dhcpcd/dist/dhcp-common.h:1.2
--- src/external/bsd/dhcpcd/dist/dhcp-common.h:1.1.1.7 Mon Oct 6 18:20:19 2014
+++ src/external/bsd/dhcpcd/dist/dhcp-common.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: dhcp-common.h,v 1.1.1.7 2014/10/06 18:20:19 roy Exp $ */
+/* $NetBSD: dhcp-common.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/ipv4.c
diff -u src/external/bsd/dhcpcd/dist/ipv4.c:1.1.1.7 src/external/bsd/dhcpcd/dist/ipv4.c:1.2
--- src/external/bsd/dhcpcd/dist/ipv4.c:1.1.1.7 Mon Jul 14 11:45:04 2014
+++ src/external/bsd/dhcpcd/dist/ipv4.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: ipv4.c,v 1.1.1.7 2014/07/14 11:45:04 roy Exp $");
+ __RCSID("$NetBSD: ipv4.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcp.c
diff -u src/external/bsd/dhcpcd/dist/dhcp.c:1.17 src/external/bsd/dhcpcd/dist/dhcp.c:1.18
--- src/external/bsd/dhcpcd/dist/dhcp.c:1.17 Sat Sep 27 01:17:34 2014
+++ src/external/bsd/dhcpcd/dist/dhcp.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: dhcp.c,v 1.17 2014/09/27 01:17:34 roy Exp $");
+ __RCSID("$NetBSD: dhcp.c,v 1.18 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
@@ -135,6 +135,7 @@ dhcp_printoptions(const struct dhcpcd_ct
const char * const *p;
size_t i, j;
const struct dhcp_opt *opt, *opt2;
+ int cols;
for (p = dhcp_params; *p; p++)
printf(" %s\n", *p);
@@ -143,11 +144,15 @@ dhcp_printoptions(const struct dhcpcd_ct
for (j = 0, opt2 = opts; j < opts_len; j++, opt2++)
if (opt->option == opt2->option)
break;
- if (j == opts_len)
- printf("%03d %s\n", opt->option, opt->var);
+ if (j == opts_len) {
+ cols = printf("%03d %s", opt->option, opt->var);
+ dhcp_print_option_encoding(opt, cols);
+ }
+ }
+ for (i = 0, opt = opts; i < opts_len; i++, opt++) {
+ cols = printf("%03d %s", opt->option, opt->var);
+ dhcp_print_option_encoding(opt, cols);
}
- for (i = 0, opt = opts; i < opts_len; i++, opt++)
- printf("%03d %s\n", opt->option, opt->var);
}
#define get_option_raw(ctx, dhcp, opt) get_option(ctx, dhcp, opt, NULL)
@@ -1272,12 +1277,12 @@ dhcp_env(char **env, const char *prefix,
}
if (*dhcp->bootfile && !(overl & 1)) {
- print_string(safe, sizeof(safe),
+ print_string(safe, sizeof(safe), STRING,
dhcp->bootfile, sizeof(dhcp->bootfile));
setvar(&ep, prefix, "filename", safe);
}
if (*dhcp->servername && !(overl & 2)) {
- print_string(safe, sizeof(safe),
+ print_string(safe, sizeof(safe), STRING | DOMAIN,
dhcp->servername, sizeof(dhcp->servername));
setvar(&ep, prefix, "server_name", safe);
}
@@ -2193,9 +2198,25 @@ log_dhcp1(int lvl, const char *msg,
struct in_addr addr;
int r;
- if (strcmp(msg, "NAK:") == 0)
+ if (strcmp(msg, "NAK:") == 0) {
a = get_option_string(iface->ctx, dhcp, DHO_MESSAGE);
- else if (ad && dhcp->yiaddr != 0) {
+ if (a) {
+ char *tmp;
+ size_t al, tmpl;
+
+ al = strlen(a);
+ tmpl = (al * 4) + 1;
+ tmp = malloc(tmpl);
+ if (tmp == NULL) {
+ syslog(LOG_ERR, "%s: %m", __func__);
+ free(a);
+ return;
+ }
+ print_string(tmp, tmpl, STRING, (uint8_t *)a, al);
+ free(a);
+ a = tmp;
+ }
+ } else if (ad && dhcp->yiaddr != 0) {
addr.s_addr = dhcp->yiaddr;
a = strdup(inet_ntoa(addr));
if (a == NULL) {
@@ -2208,7 +2229,7 @@ log_dhcp1(int lvl, const char *msg,
tfrom = "from";
r = get_option_addr(iface->ctx, &addr, dhcp, DHO_SERVERID);
if (dhcp->servername[0] && r == 0) {
- print_string(sname, sizeof(sname),
+ print_string(sname, sizeof(sname), STRING,
dhcp->servername, strlen((const char *)dhcp->servername));
if (a == NULL)
syslog(lvl, "%s: %s %s %s `%s'", iface->name, msg,
@@ -2694,7 +2715,7 @@ dhcp_handlepacket(void *arg)
{
char buf[sizeof(dhcp->chaddr) * 3];
- syslog(LOG_DEBUG, "%s: xid 0x%x is not for hwaddr %s",
+ syslog(LOG_DEBUG, "%s: xid 0x%x is for hwaddr %s",
ifp->name, ntohl(dhcp->xid),
hwaddr_ntoa(dhcp->chaddr, sizeof(dhcp->chaddr),
buf, sizeof(buf)));
Index: src/external/bsd/dhcpcd/dist/dhcp.h
diff -u src/external/bsd/dhcpcd/dist/dhcp.h:1.1.1.21 src/external/bsd/dhcpcd/dist/dhcp.h:1.2
--- src/external/bsd/dhcpcd/dist/dhcp.h:1.1.1.21 Tue Sep 16 22:23:21 2014
+++ src/external/bsd/dhcpcd/dist/dhcp.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: dhcp.h,v 1.1.1.21 2014/09/16 22:23:21 roy Exp $ */
+/* $NetBSD: dhcp.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcp6.c
diff -u src/external/bsd/dhcpcd/dist/dhcp6.c:1.1.1.17 src/external/bsd/dhcpcd/dist/dhcp6.c:1.2
--- src/external/bsd/dhcpcd/dist/dhcp6.c:1.1.1.17 Mon Oct 6 18:20:18 2014
+++ src/external/bsd/dhcpcd/dist/dhcp6.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: dhcp6.c,v 1.1.1.17 2014/10/06 18:20:18 roy Exp $");
+ __RCSID("$NetBSD: dhcp6.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcpcd-embedded.c
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-embedded.c:1.1.1.8 src/external/bsd/dhcpcd/dist/dhcpcd-embedded.c:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-embedded.c:1.1.1.8 Mon Oct 6 18:20:17 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-embedded.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: dhcpcd-embedded.c,v 1.1.1.8 2014/10/06 18:20:17 roy Exp $");
+ __RCSID("$NetBSD: dhcpcd-embedded.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* DO NOT EDIT
Index: src/external/bsd/dhcpcd/dist/duid.c
diff -u src/external/bsd/dhcpcd/dist/duid.c:1.1.1.8 src/external/bsd/dhcpcd/dist/duid.c:1.2
--- src/external/bsd/dhcpcd/dist/duid.c:1.1.1.8 Sat Jun 14 20:51:04 2014
+++ src/external/bsd/dhcpcd/dist/duid.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: duid.c,v 1.1.1.8 2014/06/14 20:51:04 roy Exp $");
+ __RCSID("$NetBSD: duid.c,v 1.2 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.8.in
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.8.in:1.7 src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.8.in:1.8
--- src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.8.in:1.7 Sat Sep 27 01:17:34 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.8.in Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-.\" $NetBSD: dhcpcd-run-hooks.8.in,v 1.7 2014/09/27 01:17:34 roy Exp $
+.\" $NetBSD: dhcpcd-run-hooks.8.in,v 1.8 2014/10/06 18:22:29 roy Exp $
.\" Copyright (c) 2006-2014 Roy Marples
.\" All rights reserved
.\"
@@ -23,7 +23,7 @@
.\" OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
.\" SUCH DAMAGE.
.\"
-.Dd September 26, 2014
+.Dd October 3, 2014
.Dt DHCPCD-RUN-HOOKS 8
.Os
.Sh NAME
@@ -137,7 +137,7 @@ and
.Ev $RC_SVCNAME .
The following variables will then be set, along with any protocol supplied
ones.
-.Bl -tag -width xnew_dhcp6_prefix
+.Bl -tag -width xnew_delegated_dhcp6_prefix
.It Ev $interface
the name of the interface.
.It Ev $reason
@@ -166,6 +166,10 @@ flags.
.It Ev $ifmtu
.Ev $interface
MTU.
+.It Ev $ifssid
+the name of the SSID the
+.Ev interface
+is connected to.
.It Ev $interface_order
A list of interfaces, in order of preference.
.It Ev $if_up
@@ -191,15 +195,7 @@ requirements specified in
.It Ev $profile
the name of the profile selected from
.Xr dhcpcd.conf 5 .
-.It Ev $new_ssid
-the name of the SSID the
-.Ev interface
-is connected to.
-.It Ev $old_ssid
-the name of the SSID the
-.Ev interface
-was connected to.
-.It Ev $new_dhcp6_prefix
+.It Ev $new_delegated_dhcp6_prefix
space separated list of delegated prefixes.
.El
.Sh FILES
@@ -219,10 +215,9 @@ in a lexical order and then finally
Please report them to
.Lk http://roy.marples.name/projects/dhcpcd
.Sh SECURITY CONSIDERATIONS
-Little validation of DHCP options is done in dhcpcd itself.
-Instead, it is up to the hooks to handle any validation needed.
-To this end, some helper functions are provided, such as valid_domainname as
-used by the
-.Pa 20-resolv.conf
-hook to ensure that the hostname is not set to an invalid value.
-valid_path is also provided, but is currently unused by a stock hook script.
+.Nm dhcpcd
+will validate the content of each option against its encoding.
+For string, ascii, raw or binhex encoding it's up to the user to validate it
+for the intended purpose.
+.Pp
+When used in a shell script, each variable must be quoted correctly.
Index: src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.in
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.in:1.1.1.20 src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.in:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.in:1.1.1.20 Mon Jul 14 11:45:05 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-run-hooks.in Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#!/bin/sh
-# $NetBSD: dhcpcd-run-hooks.in,v 1.1.1.20 2014/07/14 11:45:05 roy Exp $
+# $NetBSD: dhcpcd-run-hooks.in,v 1.2 2014/10/06 18:22:29 roy Exp $
# dhcpcd client configuration script
Index: src/external/bsd/dhcpcd/dist/dhcpcd.h
diff -u src/external/bsd/dhcpcd/dist/dhcpcd.h:1.1.1.20 src/external/bsd/dhcpcd/dist/dhcpcd.h:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd.h:1.1.1.20 Tue Sep 16 22:23:21 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: dhcpcd.h,v 1.1.1.20 2014/09/16 22:23:21 roy Exp $ */
+/* $NetBSD: dhcpcd.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcpcd.8.in
diff -u src/external/bsd/dhcpcd/dist/dhcpcd.8.in:1.31 src/external/bsd/dhcpcd/dist/dhcpcd.8.in:1.32
--- src/external/bsd/dhcpcd/dist/dhcpcd.8.in:1.31 Sat Sep 27 01:17:34 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd.8.in Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-.\" $NetBSD: dhcpcd.8.in,v 1.31 2014/09/27 01:17:34 roy Exp $
+.\" $NetBSD: dhcpcd.8.in,v 1.32 2014/10/06 18:22:29 roy Exp $
.\" Copyright (c) 2006-2014 Roy Marples
.\" All rights reserved
.\"
@@ -23,7 +23,7 @@
.\" OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
.\" SUCH DAMAGE.
.\"
-.Dd September 26, 2014
+.Dd September 30, 2014
.Dt DHCPCD 8
.Os
.Sh NAME
@@ -204,17 +204,6 @@ See
for details on how these scripts work.
.Nm
currently ignores the exit code of the script.
-.Pp
-.Nm
-sanitises each variable passed from the DHCP/RA message by encoding non
-printable characters in escaped octal and escaping the following characters:
-.D1 | \*[Am] \&; \*[Lt] \*[Gt] \&( \&) $ ` \e \*q ' \
-\*[Lt]tab\*[Gt] \*[Lt]newline\*[Gt]
-.Pp
-It is possible to reverse this encoding by passing the variable to
-.Xr unvis 1 ,
-like so:
-.D1 printf \*q%s\*q \*qvariable_name\*q | unvis
.Ss Fine tuning
You can fine-tune the behaviour of
.Nm
@@ -582,7 +571,7 @@ Pass a 2nd
.Fl U, Fl Fl dumplease option to dump a secondary lease, such as
DHCPv6 Prefix Delegation when not being mixed with another IA type.
.It Fl V, Fl Fl variables
-Display a list of option codes and the associated variable for use in
+Display a list of option codes, the associated variable and encoding for use in
.Xr dhcpcd-run-hooks 8 .
Variables are prefixed with new_ and old_ unless the option number is -.
Variables without an option are part of the DHCP message and cannot be
@@ -643,23 +632,6 @@ to rebind, reconfigure or exit need to i
so that
.Nm
knows which process to signal.
-.Pp
-.Nm
-sanitises variables using the
-.Xr svis 3
-function with the
-.Dv VIS_CTYPE
-and
-.Dv VIS_OCTAL
-flags which your libc may provide,
-or it's own compatible one if not.
-Some
-.Xr unvis 1
-implementations may not decode either correctly, depending on how they
-handle VIS_CTYPE in both
-.Xr vis 3
-and
-.Xr unvis 3 .
.Sh FILES
.Bl -ohang
.It Pa @SYSCONFDIR@/dhcpcd.conf
Index: src/external/bsd/dhcpcd/dist/dhcpcd.conf.5.in
diff -u src/external/bsd/dhcpcd/dist/dhcpcd.conf.5.in:1.11 src/external/bsd/dhcpcd/dist/dhcpcd.conf.5.in:1.12
--- src/external/bsd/dhcpcd/dist/dhcpcd.conf.5.in:1.11 Tue Sep 16 22:27:04 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd.conf.5.in Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-.\" $NetBSD: dhcpcd.conf.5.in,v 1.11 2014/09/16 22:27:04 roy Exp $
+.\" $NetBSD: dhcpcd.conf.5.in,v 1.12 2014/10/06 18:22:29 roy Exp $
.\" Copyright (c) 2006-2014 Roy Marples
.\" All rights reserved
.\"
@@ -23,7 +23,7 @@
.\" OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
.\" SUCH DAMAGE.
.\"
-.Dd September 14, 2014
+.Dd October 3, 2014
.Dt DHCPCD.CONF 5
.Os
.Sh NAME
@@ -353,13 +353,11 @@ always fork on an RA.
.It Ic ipv6ra_own
Disables kernel IPv6 Router Advertisment processing so dhcpcd can manage
addresses and routes.
-This does not work reliably on any BSD system, probably due to kernel issues.
.It Ic ipv6ra_own_default
Each time dhcpcd receives an IPv6 Router Adveristment, dhcpcd will manage
the default route only.
This allows dhcpcd to prefer an interface for outbound traffic based on metric
and/or user selection rather than the kernel.
-This does work reliably on BSD systems.
.It Ic ipv6rs
Enables IPv6 Router Advertisment solicitation.
This is on by default, but is documented here in the case where it is disabled
@@ -684,7 +682,7 @@ An IPv4 address, 4 bytes
.It Ic ip6address
An IPv6 address, 16 bytes
.It Ic string Op : Ic length
-A shell escaped string (binary data escaped as octal)
+A NVT ASCII string of printable characters.
.It Ic byte
A byte
.It Ic int16
@@ -699,6 +697,8 @@ An unsigned 32bit integer, 4 bytes
A fixed value (1) to indicate that the option is present, 0 bytes
.It Ic domain
A RFC 3397 encoded string
+.It Ic dname
+A RFC 1035 validated string
.It Ic binhex Op : Ic length
Binary data expressed as hexadecimal
.It Ic embed
Index: src/external/bsd/dhcpcd/dist/dhcpcd.conf
diff -u src/external/bsd/dhcpcd/dist/dhcpcd.conf:1.10 src/external/bsd/dhcpcd/dist/dhcpcd.conf:1.11
--- src/external/bsd/dhcpcd/dist/dhcpcd.conf:1.10 Tue Sep 16 22:27:04 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd.conf Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-# $NetBSD: dhcpcd.conf,v 1.10 2014/09/16 22:27:04 roy Exp $
+# $NetBSD: dhcpcd.conf,v 1.11 2014/10/06 18:22:29 roy Exp $
# A sample configuration for dhcpcd.
# See dhcpcd.conf(5) for details.
Index: src/external/bsd/dhcpcd/dist/if-bsd.c
diff -u src/external/bsd/dhcpcd/dist/if-bsd.c:1.10 src/external/bsd/dhcpcd/dist/if-bsd.c:1.11
--- src/external/bsd/dhcpcd/dist/if-bsd.c:1.10 Sat Sep 27 01:17:34 2014
+++ src/external/bsd/dhcpcd/dist/if-bsd.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: if-bsd.c,v 1.10 2014/09/27 01:17:34 roy Exp $");
+ __RCSID("$NetBSD: if-bsd.c,v 1.11 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
@@ -70,6 +70,13 @@
#include <syslog.h>
#include <unistd.h>
+#if defined(OpenBSD) && OpenBSD >= 201411
+/* OpenBSD dropped the global setting from sysctl but left the #define
+ * which causes a EPERM error when trying to use it.
+ * I think both the error and keeping the define are wrong, so we #undef it. */
+#undef IPV6CTL_ACCEPT_RTADV
+#endif
+
#include "config.h"
#include "common.h"
#include "dhcp.h"
@@ -551,6 +558,27 @@ if_route(const struct rt *rt, int action
#endif
#ifdef INET6
+static void
+ifa_scope(struct sockaddr_in6 *sin, unsigned int ifindex)
+{
+
+#ifdef __KAME__
+ /* KAME based systems want to store the scope inside the sin6_addr
+ * for link local addreses */
+ if (IN6_IS_ADDR_LINKLOCAL(&sin->sin6_addr)) {
+ uint16_t scope = htons(ifindex);
+ memcpy(&sin->sin6_addr.s6_addr[2], &scope,
+ sizeof(scope));
+ }
+ sin->sin6_scope_id = 0;
+#else
+ if (IN6_IS_ADDR_LINKLOCAL(&sin->sin6_addr))
+ sin->sin6_scope_id = ifindex;
+ else
+ sin->sin6_scope_id = 0;
+#endif
+}
+
int
if_address6(const struct ipv6_addr *a, int action)
{
@@ -583,6 +611,7 @@ if_address6(const struct ipv6_addr *a, i
}
ADDADDR(&ifa.ifra_addr, &a->addr);
+ ifa_scope(&ifa.ifra_addr, a->iface->index);
ipv6_mask(&mask, a->prefix_len);
ADDADDR(&ifa.ifra_prefixmask, &mask);
ifa.ifra_lifetime.ia6t_vltime = a->prefix_vltime;
@@ -616,21 +645,6 @@ if_route6(const struct rt6 *rt, int acti
if ((s = socket(PF_ROUTE, SOCK_RAW, 0)) == -1)
return -1;
-/* KAME based systems want to store the scope inside the sin6_addr
- * for link local addreses */
-#ifdef __KAME__
-#define SCOPE { \
- if (IN6_IS_ADDR_LINKLOCAL(&su.sin.sin6_addr)) { \
- uint16_t scope = htons(su.sin.sin6_scope_id); \
- memcpy(&su.sin.sin6_addr.s6_addr[2], &scope, \
- sizeof(scope)); \
- su.sin.sin6_scope_id = 0; \
- } \
- }
-#else
-#define SCOPE
-#endif
-
#define ADDSU { \
l = RT_ROUNDUP(su.sa.sa_len); \
memcpy(bp, &su, l); \
@@ -641,8 +655,8 @@ if_route6(const struct rt6 *rt, int acti
su.sin.sin6_family = AF_INET6; \
su.sin.sin6_len = sizeof(su.sin); \
(&su.sin)->sin6_addr = *addr; \
- su.sin.sin6_scope_id = scope; \
- SCOPE; \
+ if (scope) \
+ ifa_scope(&su.sin, scope); \
ADDSU; \
}
#define ADDADDR(addr) ADDADDRS(addr, 0)
@@ -684,9 +698,7 @@ if_route6(const struct rt6 *rt, int acti
return -1;
ADDADDRS(&lla->addr, rt->iface->index);
} else {
- ADDADDRS(&rt->gate,
- IN6_ARE_ADDR_EQUAL(&rt->gate, &in6addr_loopback)
- ? 0 : rt->iface->index);
+ ADDADDRS(&rt->gate, rt->iface->index);
}
}
@@ -712,7 +724,6 @@ if_route6(const struct rt6 *rt, int acti
#undef ADDADDR
#undef ADDSU
-#undef SCOPE
if (action >= 0 && rt->mtu) {
rtm.hdr.rtm_inits |= RTV_MTU;
@@ -748,7 +759,7 @@ get_addrs(int type, char *cp, struct soc
#ifdef INET6
int
-if_addrflags6(const char *ifname, const struct in6_addr *addr)
+if_addrflags6(const struct in6_addr *addr, const struct interface *ifp)
{
int s, flags;
struct in6_ifreq ifr6;
@@ -757,9 +768,10 @@ if_addrflags6(const char *ifname, const
flags = -1;
if (s != -1) {
memset(&ifr6, 0, sizeof(ifr6));
- strncpy(ifr6.ifr_name, ifname, sizeof(ifr6.ifr_name));
+ strncpy(ifr6.ifr_name, ifp->name, sizeof(ifr6.ifr_name));
ifr6.ifr_addr.sin6_family = AF_INET6;
ifr6.ifr_addr.sin6_addr = *addr;
+ ifa_scope(&ifr6.ifr_addr, ifp->index);
if (ioctl(s, SIOCGIFAFLAG_IN6, &ifr6) != -1)
flags = ifr6.ifr_ifru.ifru_flags6;
close(s);
@@ -916,9 +928,12 @@ if_managelink(struct dhcpcd_ctx *ctx)
sin6 = (struct sockaddr_in6*)(void *)
rti_info[RTAX_IFA];
ia6 = sin6->sin6_addr;
+#ifdef __KAME__
+ if (IN6_IS_ADDR_LINKLOCAL(&ia6))
+ ia6.s6_addr[2] = ia6.s6_addr[3] = '\0';
+#endif
if (rtm->rtm_type == RTM_NEWADDR) {
- ifa_flags = if_addrflags6(ifp->name,
- &ia6);
+ ifa_flags = if_addrflags6(&ia6, ifp);
if (ifa_flags == -1)
break;
} else
@@ -957,6 +972,7 @@ if_machinearch(char *str, size_t len)
}
#ifdef INET6
+#ifdef IPV6CTL_ACCEPT_RTADV
#define get_inet6_sysctl(code) inet6_sysctl(code, 0, 0)
#define set_inet6_sysctl(code, val) inet6_sysctl(code, val, 1)
static int
@@ -977,6 +993,7 @@ inet6_sysctl(int code, int val, int acti
return -1;
return val;
}
+#endif
#define del_if_nd6_flag(ifname, flag) if_nd6_flag(ifname, flag, -1)
#define get_if_nd6_flag(ifname, flag) if_nd6_flag(ifname, flag, 0)
@@ -1063,6 +1080,37 @@ if_raflush(void)
return 0;
}
+#ifdef SIOCGIFXFLAGS
+static int
+set_ifxflags(const struct interface *ifp, int own)
+{
+ struct ifreq ifr;
+ int s, flags;
+
+ s = socket(PF_INET6, SOCK_DGRAM, 0);
+ if (s == -1)
+ return -1;
+ strlcpy(ifr.ifr_name, ifp->name, sizeof(ifr.ifr_name));
+ if (ioctl(s, SIOCGIFXFLAGS, (void *)&ifr) == -1) {
+ close(s);
+ return -1;
+ }
+ flags = ifr.ifr_flags;
+ flags &= ~IFXF_NOINET6;
+ if (own)
+ flags &= ~IFXF_AUTOCONF6;
+ if (ifr.ifr_flags != flags) {
+ ifr.ifr_flags = flags;
+ if (ioctl(s, SIOCSIFXFLAGS, (void *)&ifr) == -1) {
+ close(s);
+ return -1;
+ }
+ }
+ close(s);
+ return 0;
+}
+#endif
+
int
if_checkipv6(struct dhcpcd_ctx *ctx, const struct interface *ifp, int own)
{
@@ -1119,6 +1167,10 @@ if_checkipv6(struct dhcpcd_ctx *ctx, con
}
#endif
+#ifdef SIOCGIFXFLAGS
+ set_ifxflags(ifp, own);
+#endif
+
#ifdef ND6_IFF_OVERRIDE_RTADV
override = get_if_nd6_flag(ifp->name, ND6_IFF_OVERRIDE_RTADV);
if (override == -1)
@@ -1168,6 +1220,7 @@ if_checkipv6(struct dhcpcd_ctx *ctx, con
#endif
}
+#ifdef IPV6CTL_ACCEPT_RTADV
ra = get_inet6_sysctl(IPV6CTL_ACCEPT_RTADV);
if (ra == -1)
/* The sysctl probably doesn't exist, but this isn't an
@@ -1181,7 +1234,10 @@ if_checkipv6(struct dhcpcd_ctx *ctx, con
return ra;
}
ra = 0;
-
+#else
+ ra = 0;
+ if (own) {
+#endif
/* Flush the kernel knowledge of advertised routers
* and prefixes so the kernel does not expire prefixes
* and default routes we are trying to own. */
Index: src/external/bsd/dhcpcd/dist/if-options.c
diff -u src/external/bsd/dhcpcd/dist/if-options.c:1.12 src/external/bsd/dhcpcd/dist/if-options.c:1.13
--- src/external/bsd/dhcpcd/dist/if-options.c:1.12 Tue Sep 16 22:27:04 2014
+++ src/external/bsd/dhcpcd/dist/if-options.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: if-options.c,v 1.12 2014/09/16 22:27:04 roy Exp $");
+ __RCSID("$NetBSD: if-options.c,v 1.13 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
@@ -1551,10 +1551,16 @@ err_sla:
t |= SINT32;
else if (strcasecmp(arg, "flag") == 0)
t |= FLAG;
+ else if (strcasecmp(arg, "raw") == 0)
+ t |= STRING | RAW;
+ else if (strcasecmp(arg, "ascii") == 0)
+ t |= STRING | ASCII;
else if (strcasecmp(arg, "domain") == 0)
- t |= STRING | RFC3397;
+ t |= STRING | DOMAIN | RFC3397;
+ else if (strcasecmp(arg, "dname") == 0)
+ t |= STRING | DOMAIN;
else if (strcasecmp(arg, "binhex") == 0)
- t |= BINHEX;
+ t |= STRING | BINHEX;
else if (strcasecmp(arg, "embed") == 0)
t |= EMBED;
else if (strcasecmp(arg, "encap") == 0)
@@ -1576,7 +1582,9 @@ err_sla:
"ignoring length for type `%s'", arg);
l = 0;
}
- if (t & ARRAY && t & (STRING | BINHEX)) {
+ if (t & ARRAY && t & (STRING | BINHEX) &&
+ !(t & (RFC3397 | DOMAIN)))
+ {
syslog(LOG_WARNING, "ignoring array for strings");
t &= ~ARRAY;
}
Index: src/external/bsd/dhcpcd/dist/ipv6nd.c
diff -u src/external/bsd/dhcpcd/dist/ipv6nd.c:1.12 src/external/bsd/dhcpcd/dist/ipv6nd.c:1.13
--- src/external/bsd/dhcpcd/dist/ipv6nd.c:1.12 Thu Sep 18 20:46:30 2014
+++ src/external/bsd/dhcpcd/dist/ipv6nd.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: ipv6nd.c,v 1.12 2014/09/18 20:46:30 roy Exp $");
+ __RCSID("$NetBSD: ipv6nd.c,v 1.13 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
@@ -1008,18 +1008,21 @@ ipv6nd_handlera(struct ipv6_ctx *ctx, st
ifp->name);
continue;
} else {
- l = (size_t)r;
+ l = (size_t)r + 1;
tmp = malloc(l);
if (tmp) {
decode_rfc3397(tmp, l, op, n);
l -= 1;
n = (size_t)print_string(NULL, 0,
+ STRING | ARRAY | DOMAIN,
(const uint8_t *)tmp, l);
+ n++;
opt = malloc(n);
- if (opt)
+ if (opt) {
print_string(opt, n,
+ STRING | ARRAY | DOMAIN,
(const uint8_t *)tmp, l);
- else
+ } else
syslog(LOG_ERR, "%s: %m",
__func__);
free(tmp);
Index: src/external/bsd/dhcpcd/dist/if-options.h
diff -u src/external/bsd/dhcpcd/dist/if-options.h:1.1.1.23 src/external/bsd/dhcpcd/dist/if-options.h:1.2
--- src/external/bsd/dhcpcd/dist/if-options.h:1.1.1.23 Mon Jul 14 11:45:06 2014
+++ src/external/bsd/dhcpcd/dist/if-options.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: if-options.h,v 1.1.1.23 2014/07/14 11:45:06 roy Exp $ */
+/* $NetBSD: if-options.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/ipv4ll.h
diff -u src/external/bsd/dhcpcd/dist/ipv4ll.h:1.1.1.3 src/external/bsd/dhcpcd/dist/ipv4ll.h:1.2
--- src/external/bsd/dhcpcd/dist/ipv4ll.h:1.1.1.3 Fri Jun 21 19:33:08 2013
+++ src/external/bsd/dhcpcd/dist/ipv4ll.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: ipv4ll.h,v 1.1.1.3 2013/06/21 19:33:08 roy Exp $ */
+/* $NetBSD: ipv4ll.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/script.h
diff -u src/external/bsd/dhcpcd/dist/script.h:1.1.1.3 src/external/bsd/dhcpcd/dist/script.h:1.2
--- src/external/bsd/dhcpcd/dist/script.h:1.1.1.3 Tue Sep 16 22:23:21 2014
+++ src/external/bsd/dhcpcd/dist/script.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: script.h,v 1.1.1.3 2014/09/16 22:23:21 roy Exp $ */
+/* $NetBSD: script.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/ipv6.h
diff -u src/external/bsd/dhcpcd/dist/ipv6.h:1.1.1.12 src/external/bsd/dhcpcd/dist/ipv6.h:1.2
--- src/external/bsd/dhcpcd/dist/ipv6.h:1.1.1.12 Sat Sep 27 01:14:55 2014
+++ src/external/bsd/dhcpcd/dist/ipv6.h Mon Oct 6 18:22:29 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: ipv6.h,v 1.1.1.12 2014/09/27 01:14:55 roy Exp $ */
+/* $NetBSD: ipv6.h,v 1.2 2014/10/06 18:22:29 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/script.c
diff -u src/external/bsd/dhcpcd/dist/script.c:1.9 src/external/bsd/dhcpcd/dist/script.c:1.10
--- src/external/bsd/dhcpcd/dist/script.c:1.9 Sat Sep 27 01:17:34 2014
+++ src/external/bsd/dhcpcd/dist/script.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: script.c,v 1.9 2014/09/27 01:17:34 roy Exp $");
+ __RCSID("$NetBSD: script.c,v 1.10 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
@@ -377,28 +377,20 @@ make_env(const struct interface *ifp, co
snprintf(env[elen++], e, "profile=%s", ifp->profile);
}
if (ifp->wireless) {
- const char *pfx;
-
- if (strcmp(reason, "CARRIER") == 0)
- pfx = "new_ssid=";
- else if (strcmp(reason, "NOCARRIER") == 0)
- pfx = "old_ssid=";
- else
- pfx = NULL;
- if (pfx) {
- size_t pfx_len;
- ssize_t psl;
-
- pfx_len = strlen(pfx);
- psl = print_string(NULL, 0,
+ static const char *pfx = "ifssid=";
+ size_t pfx_len;
+ ssize_t psl;
+
+ pfx_len = strlen(pfx);
+ psl = print_string(NULL, 0, ESCSTRING,
+ (const uint8_t *)ifp->ssid, ifp->ssid_len);
+ if (psl != -1) {
+ EMALLOC(elen, pfx_len + (size_t)psl + 1);
+ memcpy(env[elen], pfx, pfx_len);
+ print_string(env[elen] + pfx_len, (size_t)psl + 1,
+ ESCSTRING,
(const uint8_t *)ifp->ssid, ifp->ssid_len);
- if (psl != -1) {
- EMALLOC(elen, pfx_len + (size_t)psl + 1);
- memcpy(env[elen], pfx, pfx_len);
- print_string(env[elen] + pfx_len, (size_t)psl,
- (const uint8_t *)ifp->ssid, ifp->ssid_len);
- elen++;
- }
+ elen++;
}
}
#ifdef INET
@@ -473,9 +465,7 @@ dumplease:
}
#endif
#ifdef INET6
- if (dhcp6 && d6_state &&
- (d6_state->new || d6_state->state == DH6S_DELEGATED))
- {
+ if (dhcp6 && D6_STATE_RUNNING(ifp)) {
n = dhcp6_env(NULL, NULL, ifp,
d6_state->new, d6_state->new_len);
if (n > 0) {
Index: src/external/bsd/dhcpcd/dist/crypt/crypt.h
diff -u src/external/bsd/dhcpcd/dist/crypt/crypt.h:1.1.1.2 src/external/bsd/dhcpcd/dist/crypt/crypt.h:1.2
--- src/external/bsd/dhcpcd/dist/crypt/crypt.h:1.1.1.2 Sat Jun 14 20:51:09 2014
+++ src/external/bsd/dhcpcd/dist/crypt/crypt.h Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: crypt.h,v 1.1.1.2 2014/06/14 20:51:09 roy Exp $ */
+/* $NetBSD: crypt.h,v 1.2 2014/10/06 18:22:30 roy Exp $ */
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/crypt/hmac_md5.c
diff -u src/external/bsd/dhcpcd/dist/crypt/hmac_md5.c:1.1.1.4 src/external/bsd/dhcpcd/dist/crypt/hmac_md5.c:1.2
--- src/external/bsd/dhcpcd/dist/crypt/hmac_md5.c:1.1.1.4 Wed Jul 30 15:44:11 2014
+++ src/external/bsd/dhcpcd/dist/crypt/hmac_md5.c Mon Oct 6 18:22:30 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: hmac_md5.c,v 1.1.1.4 2014/07/30 15:44:11 roy Exp $");
+ __RCSID("$NetBSD: hmac_md5.c,v 1.2 2014/10/06 18:22:30 roy Exp $");
/*
* dhcpcd - DHCP client daemon
Index: src/external/bsd/dhcpcd/dist/dhcpcd-hooks/01-test
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-hooks/01-test:1.1.1.7 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/01-test:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-hooks/01-test:1.1.1.7 Mon Oct 6 18:20:19 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-hooks/01-test Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-# $NetBSD: 01-test,v 1.1.1.7 2014/10/06 18:20:19 roy Exp $
+# $NetBSD: 01-test,v 1.2 2014/10/06 18:22:30 roy Exp $
# Just echo our DHCP options we have
Index: src/external/bsd/dhcpcd/dist/dhcpcd-hooks/02-dump
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-hooks/02-dump:1.1.1.4 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/02-dump:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-hooks/02-dump:1.1.1.4 Mon Jul 14 11:45:06 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-hooks/02-dump Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-# $NetBSD: 02-dump,v 1.1.1.4 2014/07/14 11:45:06 roy Exp $
+# $NetBSD: 02-dump,v 1.2 2014/10/06 18:22:30 roy Exp $
# Just echo our DHCP options we have
Index: src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-mtu
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-mtu:1.1.1.8 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-mtu:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-mtu:1.1.1.8 Fri Jun 21 19:33:08 2013
+++ src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-mtu Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-# $NetBSD: 10-mtu,v 1.1.1.8 2013/06/21 19:33:08 roy Exp $
+# $NetBSD: 10-mtu,v 1.2 2014/10/06 18:22:30 roy Exp $
# Configure the MTU for the interface
Index: src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ypbind
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ypbind:1.1.1.8 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ypbind:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ypbind:1.1.1.8 Tue Sep 16 22:23:21 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ypbind Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-# $NetBSD: 50-ypbind,v 1.1.1.8 2014/09/16 22:23:21 roy Exp $
+# $NetBSD: 50-ypbind,v 1.2 2014/10/06 18:22:30 roy Exp $
# Sample dhcpcd hook for ypbind
# This script is only suitable for the BSD versions.
Index: src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-wpa_supplicant
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-wpa_supplicant:1.1.1.5 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-wpa_supplicant:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-wpa_supplicant:1.1.1.5 Tue Sep 16 22:23:21 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-hooks/10-wpa_supplicant Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-# $NetBSD: 10-wpa_supplicant,v 1.1.1.5 2014/09/16 22:23:21 roy Exp $
+# $NetBSD: 10-wpa_supplicant,v 1.2 2014/10/06 18:22:30 roy Exp $
# Start, reconfigure and stop wpa_supplicant per wireless interface.
# This is needed because wpa_supplicant lacks hotplugging of any kind
Index: src/external/bsd/dhcpcd/dist/dhcpcd-hooks/29-lookup-hostname
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-hooks/29-lookup-hostname:1.1.1.5 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/29-lookup-hostname:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-hooks/29-lookup-hostname:1.1.1.5 Fri Jun 21 19:33:08 2013
+++ src/external/bsd/dhcpcd/dist/dhcpcd-hooks/29-lookup-hostname Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-# $NetBSD: 29-lookup-hostname,v 1.1.1.5 2013/06/21 19:33:08 roy Exp $
+# $NetBSD: 29-lookup-hostname,v 1.2 2014/10/06 18:22:30 roy Exp $
# Lookup the hostname in DNS if not set
Index: src/external/bsd/dhcpcd/dist/dhcpcd-hooks/15-timezone
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-hooks/15-timezone:1.1.1.2 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/15-timezone:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-hooks/15-timezone:1.1.1.2 Sat Jun 14 20:51:09 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-hooks/15-timezone Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-# $NetBSD: 15-timezone,v 1.1.1.2 2014/06/14 20:51:09 roy Exp $
+# $NetBSD: 15-timezone,v 1.2 2014/10/06 18:22:30 roy Exp $
# Configure timezone
Index: src/external/bsd/dhcpcd/dist/dhcpcd-hooks/20-resolv.conf
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-hooks/20-resolv.conf:1.1.1.15 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/20-resolv.conf:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-hooks/20-resolv.conf:1.1.1.15 Mon Jul 14 11:45:06 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-hooks/20-resolv.conf Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-# $NetBSD: 20-resolv.conf,v 1.1.1.15 2014/07/14 11:45:06 roy Exp $
+# $NetBSD: 20-resolv.conf,v 1.2 2014/10/06 18:22:30 roy Exp $
# Generate /etc/resolv.conf
# Support resolvconf(8) if available
Index: src/external/bsd/dhcpcd/dist/dhcpcd-hooks/30-hostname
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-hooks/30-hostname:1.1.1.10 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/30-hostname:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-hooks/30-hostname:1.1.1.10 Mon Jul 29 20:35:33 2013
+++ src/external/bsd/dhcpcd/dist/dhcpcd-hooks/30-hostname Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-# $NetBSD: 30-hostname,v 1.1.1.10 2013/07/29 20:35:33 roy Exp $
+# $NetBSD: 30-hostname,v 1.2 2014/10/06 18:22:30 roy Exp $
# Set the hostname from DHCP data if required
Index: src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ntp.conf
diff -u src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ntp.conf:1.1.1.14 src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ntp.conf:1.2
--- src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ntp.conf:1.1.1.14 Tue Sep 16 22:23:21 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd-hooks/50-ntp.conf Mon Oct 6 18:22:30 2014
@@ -1,4 +1,4 @@
-# $NetBSD: 50-ntp.conf,v 1.1.1.14 2014/09/16 22:23:21 roy Exp $
+# $NetBSD: 50-ntp.conf,v 1.2 2014/10/06 18:22:30 roy Exp $
# Sample dhcpcd hook script for ntp
# Like our resolv.conf hook script, we store a database of ntp.conf files
Index: src/external/bsd/dhcpcd/dist/dhcpcd.c
diff -u src/external/bsd/dhcpcd/dist/dhcpcd.c:1.11 src/external/bsd/dhcpcd/dist/dhcpcd.c:1.12
--- src/external/bsd/dhcpcd/dist/dhcpcd.c:1.11 Sat Sep 27 11:00:07 2014
+++ src/external/bsd/dhcpcd/dist/dhcpcd.c Mon Oct 6 18:22:29 2014
@@ -1,5 +1,5 @@
#include <sys/cdefs.h>
- __RCSID("$NetBSD: dhcpcd.c,v 1.11 2014/09/27 11:00:07 roy Exp $");
+ __RCSID("$NetBSD: dhcpcd.c,v 1.12 2014/10/06 18:22:29 roy Exp $");
/*
* dhcpcd - DHCP client daemon
@@ -493,7 +493,9 @@ dhcpcd_selectprofile(struct interface *i
if (ifp->ssid_len) {
ssize_t r;
- r =print_string(pssid, sizeof(pssid), ifp->ssid, ifp->ssid_len);
+
+ r = print_string(pssid, sizeof(pssid), ESCSTRING,
+ ifp->ssid, ifp->ssid_len);
if (r == -1) {
syslog(LOG_ERR, "%s: %s: %m", ifp->name, __func__);
pssid[0] = '\0';
@@ -555,10 +557,10 @@ dhcpcd_handlecarrier(struct dhcpcd_ctx *
ifp->flags = flags;
}
- if (carrier == LINK_UNKNOWN)
- syslog(LOG_ERR, "%s: carrier_status: %m", ifname);
- /* IFF_RUNNING is checked, if needed, earlier and is OS dependant */
- else if (carrier == LINK_DOWN || (ifp->flags & IFF_UP) == 0) {
+ if (carrier == LINK_UNKNOWN) {
+ if (errno != ENOTTY) /* For example a PPP link on BSD */
+ syslog(LOG_ERR, "%s: carrier_status: %m", ifname);
+ } else if (carrier == LINK_DOWN || (ifp->flags & IFF_UP) == 0) {
if (ifp->carrier != LINK_DOWN) {
if (ifp->carrier == LINK_UP)
syslog(LOG_INFO, "%s: carrier lost", ifp->name);
@@ -641,14 +643,12 @@ dhcpcd_startinterface(void *arg)
struct if_options *ifo = ifp->options;
size_t i;
char buf[DUID_LEN * 3];
- struct timeval tv;
pre_start(ifp);
if (if_up(ifp) == -1)
syslog(LOG_ERR, "%s: if_up: %m", ifp->name);
if (ifo->options & DHCPCD_LINK) {
-link_retry:
switch (ifp->carrier) {
case LINK_UP:
break;
@@ -656,16 +656,19 @@ link_retry:
syslog(LOG_INFO, "%s: waiting for carrier", ifp->name);
return;
case LINK_UNKNOWN:
- /* No media state available, so we loop until
- * IFF_UP and IFF_RUNNING are set. */
+ /* No media state available.
+ * Any change on state such as IFF_UP and IFF_RUNNING
+ * should be reported to us via the route socket
+ * as we've done the best we can to bring the interface
+ * up at this point. */
ifp->carrier = if_carrier(ifp);
- if (ifp->carrier != LINK_UNKNOWN)
- goto link_retry;
- syslog(LOG_INFO, "%s: unknown carrier", ifp->name);
- tv.tv_sec = 0;
- tv.tv_usec = 100;
- eloop_timeout_add_tv(ifp->ctx->eloop, &tv,
- dhcpcd_startinterface, ifp);
+ if (ifp->carrier == LINK_UNKNOWN) {
+ syslog(LOG_INFO, "%s: unknown carrier",
+ ifp->name);
+ return;
+ }
+ dhcpcd_handlecarrier(ifp->ctx, ifp->carrier,
+ ifp->flags, ifp->name);
return;
}
}
@@ -1621,8 +1624,8 @@ main(int argc, char **argv)
ctx.options |= DHCPCD_WAITIP;
/* RTM_NEWADDR goes through the link socket as well which we
* need for IPv6 DAD, so we check for DHCPCD_LINK in handle_carrier
* instead.
* We also need to open this before checking for interfaces below
* so that we pickup any new addresses during the discover phase. */
ctx.link_fd = if_openlinksocket();
@@ -1728,8 +1731,8 @@ exit1:
free_globals(&ctx);
ipv4_ctxfree(&ctx);
ipv6_ctxfree(&ctx);
- dev_stop(&ctx, !(ctx.options & DHCPCD_FORKED));
- if (!(ctx.options & DHCPCD_FORKED) && control_stop(&ctx) == -1)
+ dev_stop(&ctx);
+ if (control_stop(&ctx) == -1)
syslog(LOG_ERR, "control_stop: %m:");
if (ctx.pid_fd != -1) {
close(ctx.pid_fd);
@@ -1621,8 +1624,8 @@ main(int argc, char **argv)
ctx.options |= DHCPCD_WAITIP;
/* RTM_NEWADDR goes through the link socket as well which we
- * need for IPv6 DAD, so we check for DHCPCD_LINK in handle_carrier
- * instead.
+ * need for IPv6 DAD, so we check for DHCPCD_LINK in
+ * dhcpcd_handlecarrier instead.
* We also need to open this before checking for interfaces below
* so that we pickup any new addresses during the discover phase. */